<?php
/*********************************************************************************
** The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 *
 ********************************************************************************/
/**
 * this file can be used to internationalise the strings present in the picklist
 */
$mod_strings = array(
	'LBL_ASSIGN_BUTTON'=>'zuweisen',
	'ADD_PICKLIST_VALUES'=>'Auswahllisteninhalt hinzufügen',
	'LBL_EXISTING_PICKLIST_VALUES'=>'Existierende Auswahllisteninhalt',
	'LBL_PICKLIST_ADDINFO'=>'hier neue Eingaben machen',
	'LBL_SELECT_ROLES'=>'Rollen auswählen',
	'LBL_NON_EDITABLE_PICKLIST_ENTRIES'=>'nicht veränderbare Vorgaben',
	'EDIT_PICKLIST_VALUE'=>'Auswahlliste bearbeiten',
	'LBL_EDIT_HERE'=>'ersetzen durch: ',
	'LBL_SELECT_TO_EDIT'=>'Eintrag zur bearbeitung auswählen: ',
	'DELETE_PICKLIST_VALUES'=>'Auswahllisteninhalte löschen',
	'LBL_REPLACE_WITH'=>'ersetzen durch: ',
	'ASSIGN_PICKLIST_VALUES'=>'Listeninhalt zuweisen',
	'LBL_PICKLIST_VALUES'=>'verfügbare Listeneinträge',
	'LBL_PICKLIST_VALUES_ASSIGNED_TO'=>'Listeneintrag zuweisen für ',
	'LBL_ADD_TO_OTHER_ROLES'=>'zu anderen Rollen hinzufügen',
	'LBL_OK_BUTTON_LABEL'=>'OK',
	'LBL_SELECT_ROLES'=>'Rollen auswählen',
	'LBL_DISPLAYED_VALUES'=>'Alle Listeneinträge für die Rolle sind unten angezeigt',
	
	// For Dependency picklist
	'LBL_PICKLIST_DEPENDENCY_SETUP' => 'Einstellungen der Abhängigkeiten von Auswahllisten',
	'LBL_PICKLIST_DEPENDENCY_DESCRIPTION' => 'Erstelle Abhängigkeiten zwischen den Werten der Auswahllisten in jedem Modul',
	'LBL_NEW_DEPENDENCY' => 'Neue Auswahllisten-Abhängigkeit',
	'LBL_TOOLS' => 'Werkzeuge',
	'LBL_SOURCE_FIELD' => 'Quellfeld',
	'LBL_TARGET_FIELD' => 'Zielfeld',
	'LBL_BUTTON_SELECTED_SOURCE_VALUES' => 'Wählen Sie Quellwerte',
	'LBL_SELECTED_SOURCE_VALUES_MSG' => 'Wählen Sie die Quellwerte der Auswahlliste um die Verknüpfung zu konfigurieren.',
	'LBL_ERR_CYCLIC_DEPENDENCY' => 'Die eingestellten Abhängigkeiten sind nicht zulässig, da es am Ende einer zyklischen Abhängigkeit liegt.',
	'LBL_SELECTED_VALUES' => 'Ausgewählte Werte',
	'LBL_CONFIGURE_DEPENDENCY_HELP_1' => 'Nur verknüpfte Werte der Auswahlliste des Quellfelds werden unten a ngezeigt (außer beim ersten Mal)',
	'LBL_CONFIGURE_DEPENDENCY_HELP_2' => "Wenn Sie Abhängigkeiten anderer Werte von Auswahllisten des Quellfeldes sehen oder ändern wollen, <br/>
										  müssen Sie die Werte durch einen Klick auf den <b>'Wählen Sie Quellwerte'</b>-Button, auf der rechten Seite, auswählen",
	'LBL_CONFIGURE_DEPENDENCY_HELP_3' => 'Selektierte Werte der Zielfeld-Werte werden hevorgehoben als',
	'LBL_ADD_BUTTON' => 'Wert hinzufügen',
	'LBL_EDIT_BUTTON' => 'Wert umbenennen',
	'LBL_DELETE_BUTTON' => 'Wert löschen',
	'NTC_DELETE_CONFIRMATION'=>'Sind Sie sicher, dass Sie diese Auswahllistabhängigkeit löschen wollen?',     
);
?>
